==> jc-1.4.0.tar.gz: java/security/DummyMessageDigest.h <==
// final class java.security.DummyMessageDigest

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 30d44a22b32e0331 java_security_DummyMessageDigest
// @dep_class cc2047cad8dcf75e java_security_MessageDigest
// @dep_class 7d8127440fb7dad2 java_security_MessageDigestSpi

// header file dependencies
// @dep_header java_security_MessageDigest

#include "java/security/MessageDigest.h"

#ifndef _JC_java_security_DummyMessageDigest_H_
#define _JC_java_security_DummyMessageDigest_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_MessageDigestSpi$object;

// Typedefs
typedef struct _jc_java_security_DummyMessageDigest$sub_refs	_jc_java_security_DummyMessageDigest$sub_refs;
typedef struct _jc_java_security_DummyMessageDigest$sub_nonrefs	_jc_java_security_DummyMessageDigest$sub_nonrefs;
typedef struct _jc_java_security_DummyMessageDigest$refs	_jc_java_security_DummyMessageDigest$refs;
typedef struct _jc_java_security_DummyMessageDigest$nonrefs	_jc_java_security_DummyMessageDigest$nonrefs;
typedef struct _jc_java_security_DummyMessageDigest$object	_jc_java_security_DummyMessageDigest$object;

typedef const struct _jc_java_security_DummyMessageDigest$vmethods	_jc_java_security_DummyMessageDigest$vmethods;
typedef const struct _jc_java_security_DummyMessageDigest$vtable	_jc_java_security_DummyMessageDigest$vtable;
typedef const struct _jc_java_security_DummyMessageDigest$vtype	_jc_java_security_DummyMessageDigest$vtype;

// Constructors
extern void _jc_java_security_DummyMessageDigest$method$_init$7c0c5e741bd0e821(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *, struct _jc_java_security_MessageDigestSpi$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_DummyMessageDigest$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *);
extern _jc_byte_array *_jc_java_security_DummyMessageDigest$method$engineDigest$af4966fb4f066ce0(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *);
extern jint _jc_java_security_DummyMessageDigest$method$engineDigest$f590996905113538(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *, struct _jc_byte_array *, jint, jint);
extern jint _jc_java_security_DummyMessageDigest$method$engineGetDigestLength$74fcf1ae739bccab(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *);
extern void _jc_java_security_DummyMessageDigest$method$engineReset$216e0febda0be220(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *);
extern void _jc_java_security_DummyMessageDigest$method$engineUpdate$807e0421d3c3a314(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *, jbyte);
extern void _jc_java_security_DummyMessageDigest$method$engineUpdate$d2f85b5d32010900(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_java_security_DummyMessageDigest$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_DummyMessageDigest$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_security_DummyMessageDigest$method_info$engineDigest$af4966fb4f066ce0;
extern _jc_method _jc_java_security_DummyMessageDigest$method_info$engineDigest$f590996905113538;
extern _jc_method _jc_java_security_DummyMessageDigest$method_info$engineGetDigestLength$74fcf1ae739bccab;
extern _jc_method _jc_java_security_DummyMessageDigest$method_info$engineReset$216e0febda0be220;
extern _jc_method _jc_java_security_DummyMessageDigest$method_info$engineUpdate$807e0421d3c3a314;
extern _jc_method _jc_java_security_DummyMessageDigest$method_info$engineUpdate$d2f85b5d32010900;
extern _jc_method _jc_java_security_DummyMessageDigest$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_DummyMessageDigest$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *);
	_jc_byte_array	*(*engineDigest$af4966fb4f066ce0)(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *);
	jint	(*engineDigest$f590996905113538)(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *, struct _jc_byte_array *, jint, jint);
	jint	(*engineGetDigestLength$74fcf1ae739bccab)(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *);
	void	(*engineReset$216e0febda0be220)(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *);
	void	(*engineUpdate$807e0421d3c3a314)(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *, jbyte);
	void	(*engineUpdate$d2f85b5d32010900)(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *, struct _jc_byte_array *, jint, jint);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *);
};

// Vtable
struct _jc_java_security_DummyMessageDigest$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_MessageDigestSpi$vmethods	java_security_MessageDigestSpi;
	_jc_java_security_MessageDigest$vmethods	java_security_MessageDigest;
	_jc_java_security_DummyMessageDigest$vmethods	java_security_DummyMessageDigest;
};

// Vtype
struct _jc_java_security_DummyMessageDigest$vtype {
	_jc_type			type;
	_jc_java_security_DummyMessageDigest$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_DummyMessageDigest$sub_refs {
	struct _jc_java_security_MessageDigestSpi$object	*mdSpi;
};

// Reference instance fields (object)
struct _jc_java_security_DummyMessageDigest$refs {
    _jc_java_security_DummyMessageDigest$sub_refs	java_security_DummyMessageDigest;
    _jc_java_security_MessageDigest$sub_refs	java_security_MessageDigest;
    _jc_java_security_MessageDigestSpi$sub_refs	java_security_MessageDigestSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_DummyMessageDigest$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_DummyMessageDigest$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_MessageDigestSpi$sub_nonrefs	java_security_MessageDigestSpi;
    _jc_java_security_MessageDigest$sub_nonrefs	java_security_MessageDigest;
    _jc_java_security_DummyMessageDigest$sub_nonrefs	java_security_DummyMessageDigest;
};

// Object instance structure
struct _jc_java_security_DummyMessageDigest$object {
	_jc_java_security_DummyMessageDigest$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_DummyMessageDigest$vtype	*vtype;
	_jc_java_security_DummyMessageDigest$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_DummyMessageDigest$vtype _jc_java_security_DummyMessageDigest$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_DummyMessageDigest, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_DummyMessageDigest$class_object;

#endif	/* _JC_java_security_DummyMessageDigest_H_ */

==> jc-1.4.6.tar.gz: java/security/DummyMessageDigest.h <==
// final class java.security.DummyMessageDigest

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 30d44a22b32e0331 java_security_DummyMessageDigest
// @dep_class cc2047cad8dcf75e java_security_MessageDigest
// @dep_class 7d8127440fb7dad2 java_security_MessageDigestSpi

// header file dependencies
// @dep_header java_security_MessageDigest

#include "java/security/MessageDigest.h"

#ifndef _JC_java_security_DummyMessageDigest_H_
#define _JC_java_security_DummyMessageDigest_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_MessageDigestSpi$object;

// Typedefs
typedef struct _jc_java_security_DummyMessageDigest$sub_refs	_jc_java_security_DummyMessageDigest$sub_refs;
typedef struct _jc_java_security_DummyMessageDigest$sub_nonrefs	_jc_java_security_DummyMessageDigest$sub_nonrefs;
typedef struct _jc_java_security_DummyMessageDigest$refs	_jc_java_security_DummyMessageDigest$refs;
typedef struct _jc_java_security_DummyMessageDigest$nonrefs	_jc_java_security_DummyMessageDigest$nonrefs;
typedef struct _jc_java_security_DummyMessageDigest$object	_jc_java_security_DummyMessageDigest$object;

typedef const struct _jc_java_security_DummyMessageDigest$vmethods	_jc_java_security_DummyMessageDigest$vmethods;
typedef const struct _jc_java_security_DummyMessageDigest$vtable	_jc_java_security_DummyMessageDigest$vtable;
typedef const struct _jc_java_security_DummyMessageDigest$vtype	_jc_java_security_DummyMessageDigest$vtype;

// Constructors
extern void _jc_java_security_DummyMessageDigest$method$_init$7c0c5e741bd0e821(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *, struct _jc_java_security_MessageDigestSpi$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_DummyMessageDigest$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_java_security_DummyMessageDigest$method$engineDigest$af4966fb4f066ce0(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *) _JC_JCNI_ATTR;
extern jint _jc_java_security_DummyMessageDigest$method$engineDigest$f590996905113538(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern jint _jc_java_security_DummyMessageDigest$method$engineGetDigestLength$74fcf1ae739bccab(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_DummyMessageDigest$method$engineReset$216e0febda0be220(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_DummyMessageDigest$method$engineUpdate$807e0421d3c3a314(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *, jbyte) _JC_JCNI_ATTR;
extern void _jc_java_security_DummyMessageDigest$method$engineUpdate$d2f85b5d32010900(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_security_DummyMessageDigest$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_DummyMessageDigest$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_security_DummyMessageDigest$method_info$engineDigest$af4966fb4f066ce0;
extern _jc_method _jc_java_security_DummyMessageDigest$method_info$engineDigest$f590996905113538;
extern _jc_method _jc_java_security_DummyMessageDigest$method_info$engineGetDigestLength$74fcf1ae739bccab;
extern _jc_method _jc_java_security_DummyMessageDigest$method_info$engineReset$216e0febda0be220;
extern _jc_method _jc_java_security_DummyMessageDigest$method_info$engineUpdate$807e0421d3c3a314;
extern _jc_method _jc_java_security_DummyMessageDigest$method_info$engineUpdate$d2f85b5d32010900;
extern _jc_method _jc_java_security_DummyMessageDigest$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_DummyMessageDigest$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*engineDigest$af4966fb4f066ce0)(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *) _JC_JCNI_ATTR;
	jint	(*engineDigest$f590996905113538)(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	jint	(*engineGetDigestLength$74fcf1ae739bccab)(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *) _JC_JCNI_ATTR;
	void	(*engineReset$216e0febda0be220)(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *) _JC_JCNI_ATTR;
	void	(*engineUpdate$807e0421d3c3a314)(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *, jbyte) _JC_JCNI_ATTR;
	void	(*engineUpdate$d2f85b5d32010900)(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_DummyMessageDigest$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_DummyMessageDigest$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_MessageDigestSpi$vmethods	java_security_MessageDigestSpi;
	_jc_java_security_MessageDigest$vmethods	java_security_MessageDigest;
	_jc_java_security_DummyMessageDigest$vmethods	java_security_DummyMessageDigest;
};

// Vtype
struct _jc_java_security_DummyMessageDigest$vtype {
	_jc_type			type;
	_jc_java_security_DummyMessageDigest$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_DummyMessageDigest$sub_refs {
	struct _jc_java_security_MessageDigestSpi$object	*mdSpi;
};

// Reference instance fields (object)
struct _jc_java_security_DummyMessageDigest$refs {
    _jc_java_security_DummyMessageDigest$sub_refs	java_security_DummyMessageDigest;
    _jc_java_security_MessageDigest$sub_refs	java_security_MessageDigest;
    _jc_java_security_MessageDigestSpi$sub_refs	java_security_MessageDigestSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_DummyMessageDigest$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_DummyMessageDigest$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_MessageDigestSpi$sub_nonrefs	java_security_MessageDigestSpi;
    _jc_java_security_MessageDigest$sub_nonrefs	java_security_MessageDigest;
    _jc_java_security_DummyMessageDigest$sub_nonrefs	java_security_DummyMessageDigest;
};

// Object instance structure
struct _jc_java_security_DummyMessageDigest$object {
	_jc_java_security_DummyMessageDigest$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_DummyMessageDigest$vtype	*vtype;
	_jc_java_security_DummyMessageDigest$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_DummyMessageDigest$vtype _jc_java_security_DummyMessageDigest$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_DummyMessageDigest, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_DummyMessageDigest$class_object;

#endif	/* _JC_java_security_DummyMessageDigest_H_ */
